Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Shards ¶
func ParseShards ¶
ParseShards converts and verifies a list of shards convert them into a form that can be used for routing.
Click to show internal directories.
Click to hide internal directories.